package com.ruoyi.zongzhi.controller;

import java.util.List;
import io.swagger.annotations.Api;
import javax.servlet.http.HttpServletResponse;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import com.ruoyi.common.annotation.Log;
import com.ruoyi.common.core.controller.BaseController;
import com.ruoyi.common.core.domain.AjaxResult;
import com.ruoyi.common.enums.BusinessType;
import com.ruoyi.zongzhi.domain.TcSafetyDanger;
import com.ruoyi.zongzhi.service.ITcSafetyDangerService;
import com.ruoyi.common.utils.poi.ExcelUtil;
import com.ruoyi.common.core.page.TableDataInfo;

/**
 * 监管单位Controller
 * 
 * @author ruoyi
 * @date 2023-08-10
 */
@RestController
@RequestMapping("/zongzhi/danger")
@Api(tags = " 监管单位")
public class TcSafetyDangerController extends BaseController
{
    @Autowired
    private ITcSafetyDangerService tcSafetyDangerService;

    /**
     * 查询监管单位列表
     */
    @PreAuthorize("@ss.hasPermi('zongzhi:danger:list')")
    @GetMapping("/list")
    public TableDataInfo list(TcSafetyDanger tcSafetyDanger)
    {
        startPage();
        List<TcSafetyDanger> list = tcSafetyDangerService.selectTcSafetyDangerList(tcSafetyDanger);
        return getDataTable(list);
    }

    /**
     * 导出监管单位列表
     */
    @PreAuthorize("@ss.hasPermi('zongzhi:danger:export')")
    @Log(title = "监管单位", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    public void export(HttpServletResponse response, TcSafetyDanger tcSafetyDanger)
    {
        List<TcSafetyDanger> list = tcSafetyDangerService.selectTcSafetyDangerList(tcSafetyDanger);
        ExcelUtil<TcSafetyDanger> util = new ExcelUtil<TcSafetyDanger>(TcSafetyDanger.class);
        util.exportExcel(response, list, "监管单位数据");
    }

    /**
     * 获取监管单位详细信息
     */
    @PreAuthorize("@ss.hasPermi('zongzhi:danger:query')")
    @GetMapping(value = "/{id}")
    public AjaxResult getInfo(@PathVariable("id") Long id)
    {
        return success(tcSafetyDangerService.selectTcSafetyDangerById(id));
    }

    /**
     * 新增监管单位
     */
    @PreAuthorize("@ss.hasPermi('zongzhi:danger:add')")
    @Log(title = "监管单位", businessType = BusinessType.INSERT)
    @PostMapping
    public AjaxResult add(@RequestBody TcSafetyDanger tcSafetyDanger)
    {
        return toAjax(tcSafetyDangerService.insertTcSafetyDanger(tcSafetyDanger));
    }

    /**
     * 修改监管单位
     */
    @PreAuthorize("@ss.hasPermi('zongzhi:danger:edit')")
    @Log(title = "监管单位", businessType = BusinessType.UPDATE)
    @PutMapping
    public AjaxResult edit(@RequestBody TcSafetyDanger tcSafetyDanger)
    {
        return toAjax(tcSafetyDangerService.updateTcSafetyDanger(tcSafetyDanger));
    }

    /**
     * 删除监管单位
     */
    @PreAuthorize("@ss.hasPermi('zongzhi:danger:remove')")
    @Log(title = "监管单位", businessType = BusinessType.DELETE)
	@DeleteMapping("/{ids}")
    public AjaxResult remove(@PathVariable Long[] ids)
    {
        return toAjax(tcSafetyDangerService.deleteTcSafetyDangerByIds(ids));
    }
}
