package com.ruoyi.zongzhi.service.impl;

import java.util.List;
import com.ruoyi.common.utils.DateUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import com.ruoyi.zongzhi.mapper.TcTownMapper;
import com.ruoyi.zongzhi.domain.TcTown;
import com.ruoyi.zongzhi.service.ITcTownService;

/**
 * 区域Service业务层处理
 * 
 * @author ruoyi
 * @date 2023-08-10
 */
@Service
public class TcTownServiceImpl implements ITcTownService 
{
    @Autowired
    private TcTownMapper tcTownMapper;

    /**
     * 查询区域
     * 
     * @param id 区域主键
     * @return 区域
     */
    @Override
    public TcTown selectTcTownById(Long id)
    {
        return tcTownMapper.selectTcTownById(id);
    }

    /**
     * 查询区域列表
     * 
     * @param tcTown 区域
     * @return 区域
     */
    @Override
    public List<TcTown> selectTcTownList(TcTown tcTown)
    {
        return tcTownMapper.selectTcTownList(tcTown);
    }

    /**
     * 新增区域
     * 
     * @param tcTown 区域
     * @return 结果
     */
    @Override
    public int insertTcTown(TcTown tcTown)
    {
        tcTown.setCreateTime(DateUtils.getNowDate());
        return tcTownMapper.insertTcTown(tcTown);
    }

    /**
     * 修改区域
     * 
     * @param tcTown 区域
     * @return 结果
     */
    @Override
    public int updateTcTown(TcTown tcTown)
    {
        return tcTownMapper.updateTcTown(tcTown);
    }

    /**
     * 批量删除区域
     * 
     * @param ids 需要删除的区域主键
     * @return 结果
     */
    @Override
    public int deleteTcTownByIds(Long[] ids)
    {
        return tcTownMapper.deleteTcTownByIds(ids);
    }

    /**
     * 删除区域信息
     * 
     * @param id 区域主键
     * @return 结果
     */
    @Override
    public int deleteTcTownById(Long id)
    {
        return tcTownMapper.deleteTcTownById(id);
    }


    @Override
    public String importUser(List<TcTown> tcTownList) {
        StringBuilder successMsg = new StringBuilder();
        if (!tcTownList.isEmpty()) {
            for (TcTown tcTown : tcTownList) {
                tcTownMapper.insertTcTown(tcTown);
            }
            successMsg.append("导入成功");
        } else {
            successMsg.append("导入失败，文件为空");
        }

        return successMsg.toString();
    }
}
